
"""set nonmember sender filter policy of a mailing list.

This script add, remove or show the accept_these_nonmembers sender rules.

This script is intended to be run as a bin/withlist script.

% bin/withlist -l -r accept_nonmember listname [options]

Options:
    -a /--add=address
        add address
    -r /--remove=address
        remove address
    -s /--show
        print addresses in accept_these_nonmembers 
    -h /--help
        Print usage

    listname
      listname for which the accept_these_nonmembers filter rules will be changed.

"""
__author__ = 'sfeng@stanford.edu'

import sys
import getopt

import paths
from Mailman import Utils
from Mailman import MailList
from Mailman import MemberAdaptor
from Mailman.i18n import _


try:
    True, False
except NameError:
    True = 1
    False = 0



def usage(code, msg=''):
    if code:
        fd = sys.stderr
    else:
        fd = sys.stdout
    if msg:
        print >> fd, msg
    else: 
        print >> fd, _(__doc__.replace('%', '%%'))
    sys.exit(code)


def accept_nonmember(mlist, *args):
    try:
        opts, arg = getopt.getopt(args, 'a:r:sh', ['help','add=','remove=','show'])
    except getopt.error, msg:
        usage(1, msg)

    add    = False
    show   = False
    remove = False
    addr   = ''

    for opt, arg in opts:
        if opt in ('-a', '--add'):
            add = True
            addr = arg
        elif opt in ('-r', '--remove'):
            remove = True
            addr = arg
        elif opt in ('-s', '--show'):
            show = True
        else: 
	    usage(0) 

    if add and remove: 
        msg = "Choose either add or remove, not both" 
	usage(1,msg) 

    if not addr and not show:
        msg = "Address is required"
    	usage(1,msg) 

    if add:
        try:
            mlist.accept_these_nonmembers.index(addr)
            msg = addr + " is already a member"
    	    usage(1, msg) 
        except ValueError:
            mlist.accept_these_nonmembers.append(addr)

    elif remove:
        try:
            mlist.accept_these_nonmembers.index(addr)
            mlist.accept_these_nonmembers.remove(addr)
        except ValueError:
            msg = addr + " is not a member"
    	    usage(1, msg) 

    mlist.Save()

    if show:
        for nonmember in mlist.accept_these_nonmembers:
            print _('%(nonmember)40s')


if __name__ == '__main__':
    usage(0)
