
"""change nomail status members of a mailing list.

This script sets nomail bit for a mailing list's members.  It can also
be used to set nomail bit for all members of a given mailing lists.

This script is intended to be run as a bin/withlist script, i.e.
Without any options, it shows members whose deliver is disabled.

% bin/withlist -l -r set_deliver listname [options]

Options:
    -d <y|n> /--deliver=<y|n>
        Enable or disable mail deliver.
    -h /--help
        Print usage
"""

import sys
import getopt

import paths
from Mailman import Utils
from Mailman import MemberAdaptor
from Mailman.i18n import _


try:
    True, False
except NameError:
    True = 1
    False = 0



def usage(code, msg=''):
    if code:
        fd = sys.stderr
    else:
        fd = sys.stdout
    print >> fd, _(__doc__.replace('%', '%%'))
    if msg:
        print >> fd, msg
    sys.exit(code)


def find_how(status):
    if status == MemberAdaptor.BYUSER:
        how ='by user'
    elif status == MemberAdaptor.BYADMIN:
        how = 'by the admin'
    elif status == MemberAdaptor.BYBOUNCE:
       how = 'due to bounces'
    else:
       how = 'for unknown reasons'
    return how

def set_deliver(mlist, *args):
    try:
        opts, args = getopt.getopt(args, 'd:h', ['deliver=', 'help'])
    except getopt.error, msg:
        usage(1, msg)

    for opt, args in opts:
        if opt in ('-d', '--deliver'):
	    deliver = args.lower()[0]
	    if deliver <> 'y' and deliver <> 'n':
	        usage(1, _('Bad argument to -d/--deliver: %(args)s %(deliver)s'))
        else: 
	    usage(0) 

    # If no args, show members whose deliver is disabled 
    if len(args) == 0:
        show = True
    else:
        show = False

    listname = mlist.internal_name()

    for member in mlist.getMembers():
        status = mlist.getDeliveryStatus(member)
	if show:
	    if status != MemberAdaptor.ENABLED:
                how = find_how(status)
                print _('Deliver off for member %(member)40s %(how)s')
	elif deliver == 'n' and status == MemberAdaptor.ENABLED:
	    # Disable deliver 
            print _('Deliver off for member %(member)40s')
            mlist.setDeliveryStatus(member, MemberAdaptor.BYADMIN)
	elif deliver == 'y' and status != MemberAdaptor.ENABLED:
            print _('Delvier reset to on for member %(member)40s')
            mlist.setDeliveryStatus(member, MemberAdaptor.ENABLED)

    mlist.Save()


if __name__ == '__main__':
    usage(0)
